==> haskell-hslua-module-text-1.1.0.1-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-text
version:              1.1.0.1
visibility:           public
id:                   hslua-module-text-1.1.0.1-5n8WTYuqBFECambyuQSvW1
key:                  hslua-module-text-1.1.0.1-5n8WTYuqBFECambyuQSvW1
license:              MIT
copyright:            © 2017–2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  4e67588172da6f74a5b509517739f6ca
exposed:              True
exposed-modules:      HsLua.Module.Text
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-text-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-text-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-text-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-text
hs-libraries:         HShslua-module-text-1.1.0.1-5n8WTYuqBFECambyuQSvW1
depends:
    base-4.17.2.1 hslua-core-2.3.1-2VDZctn2qUd3s4NFwio1Lo
    hslua-marshalling-2.3.1-DifY204blzyKxbPlhMj5nA
    hslua-packaging-2.3.1-CGjJg25I5HrGWrOUuQAHOz text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-text-1.1.0.1-103-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-text
version:              1.1.0.1
visibility:           public
id:                   hslua-module-text-1.1.0.1-4VuOv3PMwJgFZilt9K6Ql
key:                  hslua-module-text-1.1.0.1-4VuOv3PMwJgFZilt9K6Ql
license:              MIT
copyright:            © 2017–2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  3650072c2ce1a3f9ed0c6634e62d7811
exposed:              True
exposed-modules:      HsLua.Module.Text
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-text-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-text-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-text-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-text
hs-libraries:         HShslua-module-text-1.1.0.1-4VuOv3PMwJgFZilt9K6Ql
depends:
    base-4.17.2.1 hslua-core-2.3.1-2nzTvfsqVknCIzNS5qYfSv
    hslua-marshalling-2.3.1-3N0OYycMLCBGRAbv74DYBc
    hslua-packaging-2.3.1-JDqTJGkxtMKINxr1X5dwqB text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
